#
# spec file for package ghc-deriving-compat
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name deriving-compat
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.5
Release:        1.1
Summary:        Backports of GHC deriving extensions
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-ghc-boot-th-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-th-abstraction-devel
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-base-orphans-devel
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-tagged-devel
%endif

%description
Provides Template Haskell functions that mimic deriving extensions that were
introduced or modified in recent versions of GHC. Currently, the following
typeclasses/extensions are covered:

* Deriving 'Bounded'

* Deriving 'Enum'

* Deriving 'Ix'

* Deriving 'Eq', 'Eq1', and 'Eq2'

* Deriving 'Ord', 'Ord1', and 'Ord2'

* Deriving 'Read', 'Read1', and 'Read2'

* Deriving 'Show', 'Show1', and 'Show2'

* 'DeriveFoldable'

* 'DeriveFunctor'

* 'DeriveTraversable'

* 'GeneralizedNewtypeDeriving' (with GHC 8.2 or later)

* 'DerivingVia' (with GHC 8.2 or later)

See the "Data.Deriving" module for a full list of backported changes.

Note that some recent GHC typeclasses/extensions are not covered by this
package:

* 'DeriveDataTypeable'

* 'DeriveGeneric', which was introducted in GHC 7.2 for deriving 'Generic'
instances, and modified in GHC 7.6 to allow derivation of 'Generic1' instances.
Use 'Generics.Deriving.TH' from
'<http://hackage.haskell.org/package/generic-deriving generic-deriving>' to
derive 'Generic(1)' using Template Haskell.

* 'DeriveLift', which was introduced in GHC 8.0 for deriving 'Lift' instances.
Use 'Language.Haskell.TH.Lift' from
'<http://hackage.haskell.org/package/th-lift th-lift>' to derive 'Lift' using
Template Haskell.

* The 'Bifunctor' typeclass, which was introduced in GHC 7.10, as well as the
'Bifoldable' and 'Bitraversable' typeclasses, which were introduced in GHC 8.2.
Use 'Data.Bifunctor.TH' from '<http://hackage.haskell.org/package/bifunctors
bifunctors>' to derive these typeclasses using Template Haskell.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Mon Jul  9 2018 psimons@suse.com
- Update deriving-compat to version 0.5.
  [#]## 0.5 [2018.07.01]
  * Backport the changes to `GeneralizedNewtypeDeriving` and `DerivingVia` code
    generation from
    [Trac #15290](https://ghc.haskell.org/trac/ghc/ticket/15290).
    As a result, code generated by `deriveGND` or `deriveVia` now requires the
    `InstanceSigs` language extension. On the other hand, the generated code
    no longer requires the `ImpredicativeTypes` extension (unless any class
    methods use higher-rank types).
  * Allow building with `containers-0.6` and `template-haskell-2.14`.
  [#]## 0.4.3 [2018.06.16]
  * Fix a bug that caused debug-enabled GHC builds to panic when generating
    code from this library (see
    [Trac #15270](https://ghc.haskell.org/trac/ghc/ticket/15270)).
    The fix only affects the library's internals, so no changes are user-facing.
  [#]## 0.4.2 [2018.05.14]
  * Backport the fixes for GHC Trac
    [#14364](https://ghc.haskell.org/trac/ghc/ticket/14364)
    and
    [#14918](https://ghc.haskell.org/trac/ghc/ticket/14918),
    which significantly improve the compliation times of derived `Read`
    instances.
* Wed Mar 14 2018 psimons@suse.com
- Update deriving-compat to version 0.4.1 revision 1.
  A more detailed change log is not available.
